{
  "Comment-DrE": {
    "target_type": "Comment",
    "heading": "Comment-DrE Attributes",
    "description": "Auto-generated format for Comment (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Comment Text",
            "key": "comment_text",
            "format": false
          },
          {
            "name": "Comment Type",
            "key": "comment_type",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Comment Text",
            "key": "comment_text",
            "format": false
          },
          {
            "name": "Comment Type",
            "key": "comment_type",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "NoteLog-DrE": {
    "target_type": "NoteLog",
    "heading": "NoteLog-DrE Attributes",
    "description": "Auto-generated format for NoteLog (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Journal Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Journal Description",
            "key": "journal_description",
            "format": false
          },
          {
            "name": "Note Entry",
            "key": "note_entry",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Journal Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Associated Element",
            "key": "associated_element",
            "format": false
          },
          {
            "name": "Journal Description",
            "key": "journal_description",
            "format": false
          },
          {
            "name": "Note Entry",
            "key": "note_entry",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Informal-Tag-DrE": {
    "target_type": "Informal Tag",
    "heading": "Informal-Tag-DrE Attributes",
    "description": "Auto-generated format for Informal Tag (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Feedback Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "External-Reference-DrE": {
    "target_type": "External Reference",
    "heading": "External-Reference-DrE Attributes",
    "description": "Auto-generated format for External Reference (Create).",
    "aliases": [],
    "annotations": {},
    "family": "External Reference",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          },
          {
            "name": "Number of Pages",
            "key": "number_of_pages",
            "format": false
          },
          {
            "name": "Page Range",
            "key": "page_range",
            "format": false
          },
          {
            "name": "Publication Series",
            "key": "publication_series",
            "format": false
          },
          {
            "name": "Publication Series Volume",
            "key": "pub_series_volume",
            "format": false
          },
          {
            "name": "Publisher",
            "key": "publisher",
            "format": false
          },
          {
            "name": "First Publication Date",
            "key": "first_pub_date",
            "format": false
          },
          {
            "name": "Publication Date",
            "key": "pub_date",
            "format": false
          },
          {
            "name": "Publication City",
            "key": "pub_city",
            "format": false
          },
          {
            "name": "Publication Year",
            "key": "pub_year",
            "format": false
          },
          {
            "name": "Publication Numbers",
            "key": "pub_numbers",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          },
          {
            "name": "Number of Pages",
            "key": "number_of_pages",
            "format": false
          },
          {
            "name": "Page Range",
            "key": "page_range",
            "format": false
          },
          {
            "name": "Publication Series",
            "key": "publication_series",
            "format": false
          },
          {
            "name": "Publication Series Volume",
            "key": "pub_series_volume",
            "format": false
          },
          {
            "name": "Publisher",
            "key": "publisher",
            "format": false
          },
          {
            "name": "First Publication Date",
            "key": "first_pub_date",
            "format": false
          },
          {
            "name": "Publication Date",
            "key": "pub_date",
            "format": false
          },
          {
            "name": "Publication City",
            "key": "pub_city",
            "format": false
          },
          {
            "name": "Publication Year",
            "key": "pub_year",
            "format": false
          },
          {
            "name": "Publication Numbers",
            "key": "pub_numbers",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ExternalReference.find_external_references",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "CitedDocument"
        ]
      }
    },
    "get_additional_props": null
  },
  "External-Data-Source-DrE": {
    "target_type": "External Data Source",
    "heading": "External-Data-Source-DrE Attributes",
    "description": "Auto-generated format for External Data Source (Create).",
    "aliases": [],
    "annotations": {},
    "family": "External Reference",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Reference Title",
            "key": "reference_title",
            "format": false
          },
          {
            "name": "Reference Abstract",
            "key": "reference_abstract",
            "format": false
          },
          {
            "name": "Authors",
            "key": "authors",
            "format": false
          },
          {
            "name": "Organization",
            "key": "organization",
            "format": false
          },
          {
            "name": "Sources",
            "key": "reference_sources",
            "format": false
          },
          {
            "name": "License",
            "key": "license",
            "format": false
          },
          {
            "name": "Copyright",
            "key": "copyright",
            "format": false
          },
          {
            "name": "Attribution",
            "key": "category",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ExternalReference.find_external_references",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ExternalDataSource"
        ]
      }
    },
    "get_additional_props": null
  },
  "Collection-DrE": {
    "target_type": "Collection",
    "heading": "Collection-DrE Attributes",
    "description": "Auto-generated format for Collection (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Digital-Product-Catalog-DrE": {
    "target_type": "Digital Product Catalog",
    "heading": "Digital-Product-Catalog-DrE Attributes",
    "description": "Auto-generated format for Digital Product Catalog (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Digital-Product-DrE": {
    "target_type": "Digital Product",
    "heading": "Digital-Product-DrE Attributes",
    "description": "Auto-generated format for Digital Product (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Product Name",
            "key": "product_name",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Maturity",
            "key": "maturity",
            "format": false
          },
          {
            "name": "Service Life",
            "key": "service_life",
            "format": false
          },
          {
            "name": "Introduction Date",
            "key": "introduction_date",
            "format": false
          },
          {
            "name": "Next Version Date",
            "key": "next_version_date",
            "format": false
          },
          {
            "name": "Withdrawal Date",
            "key": "withdrawal_date",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          },
          {
            "name": "Agreements",
            "key": "agreements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Product Name",
            "key": "product_name",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Maturity",
            "key": "maturity",
            "format": false
          },
          {
            "name": "Service Life",
            "key": "service_life",
            "format": false
          },
          {
            "name": "Introduction Date",
            "key": "introduction_date",
            "format": false
          },
          {
            "name": "Next Version Date",
            "key": "next_version_date",
            "format": false
          },
          {
            "name": "Withdrawal Date",
            "key": "withdrawal_date",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          },
          {
            "name": "Agreements",
            "key": "agreements",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DigitalProduct"
        ]
      }
    },
    "get_additional_props": null
  },
  "Agreement-DrE": {
    "target_type": "Agreement",
    "heading": "Agreement-DrE Attributes",
    "description": "Auto-generated format for Agreement (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "agreement_identifier",
            "format": false
          },
          {
            "name": "Agreement Actors",
            "key": "agreement_actors",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "agreement_identifier",
            "format": false
          },
          {
            "name": "Agreement Actors",
            "key": "agreement_actors",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Agreement"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Sharing-Agreement-DrE": {
    "target_type": "Data Sharing Agreement",
    "heading": "Data-Sharing-Agreement-DrE Attributes",
    "description": "Auto-generated format for Data Sharing Agreement (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Product Manager",
            "key": "product_manager",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "DataSharingAgreement"
        ]
      }
    },
    "get_additional_props": null
  },
  "Digital-Subscription-DrE": {
    "target_type": "Digital Subscription",
    "heading": "Digital-Subscription-DrE Attributes",
    "description": "Auto-generated format for Digital Subscription (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Support Level",
            "key": "support_level",
            "format": false
          },
          {
            "name": "Service Levels",
            "key": "service_levels",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Support Level",
            "key": "support_level",
            "format": false
          },
          {
            "name": "Service Levels",
            "key": "service_levels",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DigitalSubscription"
        ]
      }
    },
    "get_additional_props": null
  },
  "CSV-File-DrE": {
    "target_type": "CSV File",
    "heading": "CSV-File-DrE Attributes",
    "description": "Auto-generated format for CSV File (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Digital Product Manager",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "File Path",
            "key": "file_path",
            "format": false
          },
          {
            "name": "File Encoding",
            "key": "file_encoding",
            "format": false
          },
          {
            "name": "File Extension",
            "key": "file_extension",
            "format": false
          },
          {
            "name": "File System Name",
            "key": "file_system_name",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "File Path",
            "key": "file_path",
            "format": false
          },
          {
            "name": "File Encoding",
            "key": "file_encoding",
            "format": false
          },
          {
            "name": "File Extension",
            "key": "file_extension",
            "format": false
          },
          {
            "name": "File System Name",
            "key": "file_system_name",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "Data-Dictionary-DrE": {
    "target_type": "Data Dictionary",
    "heading": "Data-Dictionary-DrE Attributes",
    "description": "Auto-generated format for Data Dictionary (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataDictionary"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Specification-DrE": {
    "target_type": "Data Specification",
    "heading": "Data-Specification-DrE Attributes",
    "description": "Auto-generated format for Data Specification (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataSpec"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Structure-DrE": {
    "target_type": "Data Structure",
    "heading": "Data-Structure-DrE Attributes",
    "description": "Auto-generated format for Data Structure (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "In Data Specification",
            "key": "in_data_spec",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "In Data Specification",
            "key": "in_data_spec",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_structures",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Data-Field-DrE": {
    "target_type": "Data Field",
    "heading": "Data-Field-DrE Attributes",
    "description": "Auto-generated format for Data Field (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Position",
            "key": "position",
            "format": false
          },
          {
            "name": "Minimum Cardinality",
            "key": "min_cardinality",
            "format": false
          },
          {
            "name": "Maximum Cardinality",
            "key": "max_cardinality",
            "format": false
          },
          {
            "name": "In Data Structure",
            "key": "in_data_structure",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Data Class",
            "key": "data_class",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Minimum Length",
            "key": "min_length",
            "format": false
          },
          {
            "name": "Length",
            "key": "length",
            "format": false
          },
          {
            "name": "Precision",
            "key": "precision",
            "format": false
          },
          {
            "name": "Ordered Values",
            "key": "ordered_values",
            "format": false
          },
          {
            "name": "Units",
            "key": "units",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Position",
            "key": "position",
            "format": false
          },
          {
            "name": "Minimum Cardinality",
            "key": "min_cardinality",
            "format": false
          },
          {
            "name": "Maximum Cardinality",
            "key": "max_cardinality",
            "format": false
          },
          {
            "name": "In Data Structure",
            "key": "in_data_structure",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Data Class",
            "key": "data_class",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Minimum Length",
            "key": "min_length",
            "format": false
          },
          {
            "name": "Length",
            "key": "length",
            "format": false
          },
          {
            "name": "Precision",
            "key": "precision",
            "format": false
          },
          {
            "name": "Ordered Values",
            "key": "ordered_values",
            "format": false
          },
          {
            "name": "Units",
            "key": "units",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_fields",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Data-Class-DrE": {
    "target_type": "Data Class",
    "heading": "Data-Class-DrE Attributes",
    "description": "Auto-generated format for Data Class (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Data Designer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Namespace",
            "key": "namespace",
            "format": false
          },
          {
            "name": "Match Property Names",
            "key": "match_property_names",
            "format": false
          },
          {
            "name": "Match Threshold",
            "key": "match_threshold",
            "format": false
          },
          {
            "name": "IsCaseSensitive",
            "key": "is_case_sensitive",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Allow Duplicate Values",
            "key": "duplicates_allowed",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          },
          {
            "name": "Average Value",
            "key": "avg_value",
            "format": false
          },
          {
            "name": "Value List",
            "key": "value_list",
            "format": false
          },
          {
            "name": "Value Range From",
            "key": "value_range_from",
            "format": false
          },
          {
            "name": "Value Range To",
            "key": "value_range_to",
            "format": false
          },
          {
            "name": "Sample Values",
            "key": "sample_values",
            "format": false
          },
          {
            "name": "Data Patterns",
            "key": "data_patterns",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Containing Data Class",
            "key": "containing_data_class",
            "format": false
          },
          {
            "name": "Specializes Data Class",
            "key": "specializes_data_class",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Namespace",
            "key": "namespace",
            "format": false
          },
          {
            "name": "Match Property Names",
            "key": "match_property_names",
            "format": false
          },
          {
            "name": "Match Threshold",
            "key": "match_threshold",
            "format": false
          },
          {
            "name": "IsCaseSensitive",
            "key": "is_case_sensitive",
            "format": false
          },
          {
            "name": "Data Type",
            "key": "data_type",
            "format": false
          },
          {
            "name": "Allow Duplicate Values",
            "key": "duplicates_allowed",
            "format": false
          },
          {
            "name": "isNullable",
            "key": "is_nullable",
            "format": false
          },
          {
            "name": "Default Value",
            "key": "default_value",
            "format": false
          },
          {
            "name": "Average Value",
            "key": "avg_value",
            "format": false
          },
          {
            "name": "Value List",
            "key": "value_list",
            "format": false
          },
          {
            "name": "Value Range From",
            "key": "value_range_from",
            "format": false
          },
          {
            "name": "Value Range To",
            "key": "value_range_to",
            "format": false
          },
          {
            "name": "Sample Values",
            "key": "sample_values",
            "format": false
          },
          {
            "name": "Data Patterns",
            "key": "data_patterns",
            "format": false
          },
          {
            "name": "In Data Dictionary",
            "key": "in_data_dictionary",
            "format": false
          },
          {
            "name": "Containing Data Class",
            "key": "containing_data_class",
            "format": false
          },
          {
            "name": "Specializes Data Class",
            "key": "specializes_data_class",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "DataDesigner.find_data_classes",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Information-Supply-Chain-DrE": {
    "target_type": "Information Supply Chain",
    "heading": "Information-Supply-Chain-DrE Attributes",
    "description": "Auto-generated format for Information Supply Chain (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Nested Information Supply Chains",
            "key": "nested_info_supply_chains",
            "format": false
          },
          {
            "name": "In Information Supply Chain",
            "key": "in_supply_chain",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Nested Information Supply Chains",
            "key": "nested_info_supply_chains",
            "format": false
          },
          {
            "name": "In Information Supply Chain",
            "key": "in_supply_chain",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_information_supply_chains",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Blueprint-DrE": {
    "target_type": "Solution Blueprint",
    "heading": "Solution-Blueprint-DrE Attributes",
    "description": "Auto-generated format for Solution Blueprint (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Components",
            "key": "solution_components",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Components",
            "key": "solution_components",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_blueprints",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Component-DrE": {
    "target_type": "Solution Component",
    "heading": "Solution-Component-DrE Attributes",
    "description": "Auto-generated format for Solution Component (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Component Type",
            "key": "soln_comp_type",
            "format": false
          },
          {
            "name": "Planned Deployed Implementation Type",
            "key": "planned_deployed_impl_type",
            "format": false
          },
          {
            "name": "In Solution Components",
            "key": "in_components",
            "format": false
          },
          {
            "name": "In Solution Blueprints",
            "key": "solution_blueprints",
            "format": false
          },
          {
            "name": "In Information Supply Chains",
            "key": "in_supply_chains",
            "format": false
          },
          {
            "name": "Actors",
            "key": "actors",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Solution Component Type",
            "key": "soln_comp_type",
            "format": false
          },
          {
            "name": "Planned Deployed Implementation Type",
            "key": "planned_deployed_impl_type",
            "format": false
          },
          {
            "name": "In Solution Components",
            "key": "in_components",
            "format": false
          },
          {
            "name": "In Solution Blueprints",
            "key": "solution_blueprints",
            "format": false
          },
          {
            "name": "In Information Supply Chains",
            "key": "in_supply_chains",
            "format": false
          },
          {
            "name": "Actors",
            "key": "actors",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_components",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Solution-Role-DrE": {
    "target_type": "Solution Role",
    "heading": "Solution-Role-DrE Attributes",
    "description": "Auto-generated format for Solution Role (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Solution Architect",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Name",
            "key": "name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Title",
            "key": "title",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Name",
            "key": "name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Title",
            "key": "title",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "SolutionArchitect.find_solution_roles",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Glossary-DrE": {
    "target_type": "Glossary",
    "heading": "Glossary-DrE Attributes",
    "description": "Auto-generated format for Glossary (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Glossary",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Language",
            "key": "language",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Language",
            "key": "language",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "CollectionManager.find_collections",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Glossary"
        ]
      }
    },
    "get_additional_props": null
  },
  "Glossary-Term-DrE": {
    "target_type": "Glossary Term",
    "heading": "Glossary-Term-DrE Attributes",
    "description": "Auto-generated format for Glossary Term (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Glossary",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "term_name",
            "format": false
          },
          {
            "name": "Glossary",
            "key": "glossary_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Folders",
            "key": "folders",
            "format": false
          },
          {
            "name": "Abbreviation",
            "key": "abbreviation",
            "format": false
          },
          {
            "name": "Example",
            "key": "example",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "term_name",
            "format": false
          },
          {
            "name": "Glossary",
            "key": "glossary_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Folders",
            "key": "folders",
            "format": false
          },
          {
            "name": "Abbreviation",
            "key": "abbreviation",
            "format": false
          },
          {
            "name": "Example",
            "key": "example",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GlossaryManager.find_glossary_terms",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Project-DrE": {
    "target_type": "Project",
    "heading": "Project-DrE Attributes",
    "description": "Auto-generated format for Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {}
    },
    "get_additional_props": null
  },
  "Campaign-DrE": {
    "target_type": "Campaign",
    "heading": "Campaign-DrE Attributes",
    "description": "Auto-generated format for Campaign (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "Campaign"
        ]
      }
    },
    "get_additional_props": null
  },
  "Task-DrE": {
    "target_type": "Task",
    "heading": "Task-DrE Attributes",
    "description": "Auto-generated format for Task (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "Task"
        ]
      }
    },
    "get_additional_props": null
  },
  "Personal-Project-DrE": {
    "target_type": "Personal Project",
    "heading": "Personal-Project-DrE Attributes",
    "description": "Auto-generated format for Personal Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "PersonalProject"
        ]
      }
    },
    "get_additional_props": null
  },
  "Study-Project-DrE": {
    "target_type": "Study Project",
    "heading": "Study-Project-DrE Attributes",
    "description": "Auto-generated format for Study Project (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Project",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Project Type",
            "key": "project_type",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "project_identifier",
            "format": false
          },
          {
            "name": "Mission",
            "key": "mission",
            "format": false
          },
          {
            "name": "Purposes",
            "key": "purposes",
            "format": false
          },
          {
            "name": "Start Date",
            "key": "start_date",
            "format": false
          },
          {
            "name": "Planned End Date",
            "key": "end_date",
            "format": false
          },
          {
            "name": "Priority",
            "key": "priority",
            "format": false
          },
          {
            "name": "Project Phase",
            "key": "project_phase",
            "format": false
          },
          {
            "name": "Project Status",
            "key": "project_status",
            "format": false
          },
          {
            "name": "Project Health",
            "key": "project_health",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "ProjectManager.find_projects",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "classification_names": [
          "StudyProject"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Driver-DrE": {
    "target_type": "Governance Driver",
    "heading": "Governance-Driver-DrE Attributes",
    "description": "Auto-generated format for Governance Driver (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceDriver"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Strategy-DrE": {
    "target_type": "Governance Strategy",
    "heading": "Governance-Strategy-DrE Attributes",
    "description": "Auto-generated format for Governance Strategy (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceStrategy"
        ]
      }
    },
    "get_additional_props": null
  },
  "Business-Imperative-DrE": {
    "target_type": "Business Imperative",
    "heading": "Business-Imperative-DrE Attributes",
    "description": "Auto-generated format for Business Imperative (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceDriver"
        ]
      }
    },
    "get_additional_props": null
  },
  "Regulation-DrE": {
    "target_type": "Regulation",
    "heading": "Regulation-DrE Attributes",
    "description": "Auto-generated format for Regulation (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Regulation Source",
            "key": "regulation_source",
            "format": false
          },
          {
            "name": "Regulators",
            "key": "regulators",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Regulation Source",
            "key": "regulation_source",
            "format": false
          },
          {
            "name": "Regulators",
            "key": "regulators",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "Regulation"
        ]
      }
    },
    "get_additional_props": null
  },
  "Regulation-Article-DrE": {
    "target_type": "Regulation Article",
    "heading": "Regulation-Article-DrE Attributes",
    "description": "Auto-generated format for Regulation Article (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "RegulationArticle"
        ]
      }
    },
    "get_additional_props": null
  },
  "Threat-Definition-DrE": {
    "target_type": "Threat Definition",
    "heading": "Threat-Definition-DrE Attributes",
    "description": "Auto-generated format for Threat Definition (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ThreatDefinition"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Policy-DrE": {
    "target_type": "Governance Policy",
    "heading": "Governance-Policy-DrE Attributes",
    "description": "Auto-generated format for Governance Policy (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernancePolicy"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Principle-DrE": {
    "target_type": "Governance Principle",
    "heading": "Governance-Principle-DrE Attributes",
    "description": "Auto-generated format for Governance Principle (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernancePrinciple"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Obligation-DrE": {
    "target_type": "Governance Obligation",
    "heading": "Governance-Obligation-DrE Attributes",
    "description": "Auto-generated format for Governance Obligation (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceObligation"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Approach-DrE": {
    "target_type": "Governance Approach",
    "heading": "Governance-Approach-DrE Attributes",
    "description": "Auto-generated format for Governance Approach (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceApproach"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Control-DrE": {
    "target_type": "Governance Control",
    "heading": "Governance-Control-DrE Attributes",
    "description": "Auto-generated format for Governance Control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "measurement",
            "key": "measurement",
            "format": false
          },
          {
            "name": "target",
            "key": "target",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "measurement",
            "key": "measurement",
            "format": false
          },
          {
            "name": "target",
            "key": "target",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceMetric"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Action-DrE": {
    "target_type": "Governance Action",
    "heading": "Governance-Action-DrE Attributes",
    "description": "Auto-generated format for Governance Action (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceAction"
        ]
      }
    },
    "get_additional_props": null
  },
  "Data-Processing-Purpose-DrE": {
    "target_type": "Data Processing Purpose",
    "heading": "Data-Processing-Purpose-DrE Attributes",
    "description": "Auto-generated format for Data Processing Purpose (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "DataProcessingPurpose"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Rule-DrE": {
    "target_type": "Governance Rule",
    "heading": "Governance-Rule-DrE Attributes",
    "description": "Auto-generated format for Governance Rule (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceRule"
        ]
      }
    },
    "get_additional_props": null
  },
  "Service-Level-Objectives-DrE": {
    "target_type": "Service Level Objectives",
    "heading": "Service-Level-Objectives-DrE Attributes",
    "description": "Auto-generated format for Service Level Objectives (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "ServiceLevelObjectives"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Responsibility-DrE": {
    "target_type": "Governance Responsibility",
    "heading": "Governance-Responsibility-DrE Attributes",
    "description": "Auto-generated format for Governance Responsibility (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceResponsibility"
        ]
      }
    },
    "get_additional_props": null
  },
  "Governance-Procedure-DrE": {
    "target_type": "Governance Procedure",
    "heading": "Governance-Procedure-DrE Attributes",
    "description": "Auto-generated format for Governance Procedure (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceProcedure"
        ]
      }
    },
    "get_additional_props": null
  },
  "Security-Access-Control-DrE": {
    "target_type": "Security Access Control",
    "heading": "Security-Access-Control-DrE Attributes",
    "description": "Auto-generated format for Security Access Control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "SecurityAccessControl"
        ]
      }
    },
    "get_additional_props": null
  },
  "security_access_control-DrE": {
    "target_type": "security_access_control",
    "heading": "security_access_control-DrE Attributes",
    "description": "Auto-generated format for security_access_control (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "criteria",
            "key": "criteria",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "criteria",
            "key": "criteria",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "GovernanceZone"
        ]
      }
    },
    "get_additional_props": null
  },
  "Security-Group-DrE": {
    "target_type": "Security Group",
    "heading": "Security-Group-DrE Attributes",
    "description": "Auto-generated format for Security Group (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Identifier",
            "key": "identifier",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "SEcurityGroup"
        ]
      }
    },
    "get_additional_props": null
  },
  "Naming-Standard-Rule-DrE": {
    "target_type": "Naming Standard Rule",
    "heading": "Naming-Standard-Rule-DrE Attributes",
    "description": "Auto-generated format for Naming Standard Rule (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Name Patterns",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implementation Description",
            "key": "implementation_description",
            "format": false
          },
          {
            "name": "Supports Policies",
            "key": "supports_policies",
            "format": false
          },
          {
            "name": "Name Patterns",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          }
        ]
      }
    ],
    "action": {
      "function": "GovernanceOfficer.find_governance_definitions",
      "required_params": [
        "search_string"
      ],
      "optional_params": [
        "page_size",
        "start_from",
        "starts_with",
        "ends_with",
        "ignore_case"
      ],
      "spec_params": {
        "metadata_element_types": [
          "NamingStandardRule"
        ]
      }
    },
    "get_additional_props": null
  },
  "Certification-Type-DrE": {
    "target_type": "Certification Type",
    "heading": "Certification-Type-DrE Attributes",
    "description": "Auto-generated format for Certification Type (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  },
  "License-Type-DrE": {
    "target_type": "License Type",
    "heading": "License-Type-DrE Attributes",
    "description": "Auto-generated format for License Type (Create).",
    "aliases": [],
    "annotations": {},
    "family": "Governance Officer",
    "formats": [
      {
        "types": [
          "ALL"
        ],
        "attributes": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ],
        "columns": [
          {
            "name": "Display Name",
            "key": "display_name",
            "format": false
          },
          {
            "name": "Document Identifier",
            "key": "document_identifier",
            "format": false
          },
          {
            "name": "Domain Identifier",
            "key": "domain_identifier",
            "format": false
          },
          {
            "name": "Summary",
            "key": "summary",
            "format": false
          },
          {
            "name": "Scope",
            "key": "scope",
            "format": false
          },
          {
            "name": "Usage",
            "key": "usage",
            "format": false
          },
          {
            "name": "Importance",
            "key": "importance",
            "format": false
          },
          {
            "name": "Implications",
            "key": "implications",
            "format": false
          },
          {
            "name": "Outcomes",
            "key": "outcomes",
            "format": false
          },
          {
            "name": "Results",
            "key": "results",
            "format": false
          },
          {
            "name": "Description",
            "key": "description",
            "format": false
          },
          {
            "name": "Details",
            "key": "details",
            "format": false
          },
          {
            "name": "Restrictions",
            "key": "restrictions",
            "format": false
          },
          {
            "name": "Obligations",
            "key": "obligations",
            "format": false
          },
          {
            "name": "Entitlements",
            "key": "Entitlements",
            "format": false
          }
        ]
      }
    ],
    "action": null,
    "get_additional_props": null
  }
}


"""
SPDX-License-Identifier: Apache-2.0
Copyright Contributors to the ODPi Egeria project.

 Asset Catalog View Service Methods - Search for assets, retrieve their properties, lineage and related glossary
 information.

 This file is in active development...

"""

import asyncio
import json

from httpx import Response
from pyegeria.utils import body_slimmer
from pyegeria._client import Client
from pyegeria._globals import TEMPLATE_GUIDS, max_paging_size
from pyegeria._exceptions import InvalidParameterException
from pyegeria._globals import NO_ELEMENTS_FOUND, NO_ASSETS_FOUND
from ._validators import validate_search_string


class AssetCatalog(Client):
    """Set up and maintain automation services in Egeria.

    Attributes:
        view_server : str
            The name of the View Server to use.
        platform_url : str
            URL of the server platform to connect to
        user_id : str
            The identity of the user calling the method - this sets a default optionally used by the methods
            when the user doesn't pass the user_id on a method call.
        user_pwd: str
            The password associated with the user_id. Defaults to None

    """

    def __init__(
        self,
        view_server: str,
        platform_url: str,
        user_id: str,
        user_pwd: str = None,
        token: str = None,
    ):
        self.view_server = view_server
        self.platform_url = platform_url
        self.user_id = user_id
        self.user_pwd = user_pwd
        Client.__init__(self, view_server, platform_url, user_id, user_pwd, token=token)

    async def _async_create_element_from_template(self, body: dict) -> str:
        """Create a new metadata element from a template.  Async version.
        Parameters
        ----------
        body : str
            The json body used to instantiate the template.

        Returns
        -------
        Response
           The guid of the resulting element

        Raises
        ------
        InvalidParameterException
        PropertyServerException
        UserNotAuthorizedException

        Notes
        -----
        See also: https://egeria-project.org/features/templated-cataloguing/overview/
        The full description of the body is shown below:
           {
             "typeName" : "",
             "initialStatus" : "",
             "initialClassifications" : "",
             "anchorGUID" : "",
             "isOwnAnchor" : "",
             "effectiveFrom" : "",
             "effectiveTo" : "",
             "templateGUID" : "",
             "templateProperties" : {},
             "placeholderPropertyValues" : {
               "placeholderPropertyName1" : "placeholderPropertyValue1",
               "placeholderPropertyName2" : "placeholderPropertyValue2"
             },
             "parentGUID" : "",
             "parentRelationshipTypeName" : "",
             "parentRelationshipProperties" : "",
             "parentAtEnd1" : "",
             "effectiveTime" : ""
           }
        """

        url = f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/automated-curation/catalog-templates/new-element"
        response = await self._async_make_request("POST", url, body)
        return response.json().get("guid", "GUID failed to be returned")

    def create_element_from_template(self, body: dict) -> str:
        """Create a new metadata element from a template.  Async version.
        Parameters
        ----------
        body : str
             The json body used to instantiate the template.
        server : str, optional
            The name of the view server to use. If not provided, the default server name will be used.

        Returns
        -------
        Response
            The guid of the resulting element

         Raises
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

         Notes
         -----
         See also: https://egeria-project.org/features/templated-cataloguing/overview/
         The full description of the body is shown below:
             {
               "typeName" : "",
               "initialStatus" : "",
               "initialClassifications" : "",
               "anchorGUID" : "",
               "isOwnAnchor" : "",
               "effectiveFrom" : "",
               "effectiveTo" : "",
               "templateGUID" : "",
               "templateProperties" : {},
               "placeholderPropertyValues" : {
                 "placeholderPropertyName1" : "placeholderPropertyValue1",
                 "placeholderPropertyName2" : "placeholderPropertyValue2"
               },
               "parentGUID" : "",
               "parentRelationshipTypeName" : "",
               "parentRelationshipProperties" : "",
               "parentAtEnd1" : "",
               "effectiveTime" : ""
             }
        """
        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_create_element_from_template(body)
        )
        return response

    async def _async_create_kafka_server_element_from_template(
        self, kafka_server: str, host_name: str, port: str
    ) -> str:
        """Create a Kafka server element from a template. Async version.

        Parameters
        ----------
        kafka_server : str
            The name of the Kafka server.

        host_name : str
            The host name of the Kafka server.

        port : str
            The port number of the Kafka server.

        Returns
        -------
        str
            The GUID of the Kafka server element.
        """

        body = {
            "templateGUID": TEMPLATE_GUIDS["Apache Kafka Server"],
            "isOwnAnchor": "true",
            "placeholderPropertyValues": {
                "serverName": kafka_server,
                "hostIdentifier": host_name,
                "portNumber": port,
            },
        }
        response = await self._async_create_element_from_template(body)
        return response

    def create_kafka_server_element_from_template(
        self, kafka_server: str, host_name: str, port: str
    ) -> str:
        """Create a Kafka server element from a template.

        Parameters
        ----------
        kafka_server : str
            The name of the Kafka server.

        host_name : str
            The host name of the Kafka server.

        port : str
            The port number of the Kafka server.

        Returns
        -------
        str
            The GUID of the Kafka server element.
        """
        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_create_kafka_server_element_from_template(
                kafka_server, host_name, port
            )
        )
        return response

    async def _async_create_postgres_server_element_from_template(
        self,
        postgres_server: str,
        host_name: str,
        port: str,
        db_user: str,
        db_pwd: str,
    ) -> str:
        """Create a Postgres server element from a template. Async version.

        Parameters
        ----------
        postgres_server : str
            The name of the Postgres server.

        host_name : str
            The host name of the Postgres server.

        port : str
            The port number of the Postgres server.

        db_user: str
            User name to connect to the database

        db_pwd: str
            User password to connect to the database

        Returns
        -------
        str
            The GUID of the Kafka server element.
        """
        body = {
            "templateGUID": TEMPLATE_GUIDS["PostgreSQL Server"],
            "isOwnAnchor": "true",
            "placeholderPropertyValues": {
                "serverName": postgres_server,
                "hostIdentifier": host_name,
                "portNumber": port,
                "databaseUserId": db_user,
                "databasePassword": db_pwd,
            },
        }
        response = await self._async_create_element_from_template(body)
        return response

    def create_postgres_server_element_from_template(
        self,
        postgres_server: str,
        host_name: str,
        port: str,
        db_user: str,
        db_pwd: str,
    ) -> str:
        """Create a Postgres server element from a template.

        Parameters
        ----------
        postgres_server : str
            The name of the Postgres server.

        host_name : str
            The host name of the Postgres server.

        port : str
            The port number of the Postgres server.

        db_user: str
            User name to connect to the database

        db_pwd: str
            User password to connect to the database

        Returns
        -------
        str
            The GUID of the Postgres server element.
        """
        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_create_postgres_server_element_from_template(
                postgres_server, host_name, port, db_user, db_pwd
            )
        )
        return response

    #
    # Engine Actions
    #

    async def _async_find_in_asset_domain(
        self,
        search_string: str,
        start_from: int = 0,
        page_size: int = max_paging_size,
        starts_with: bool = True,
        ends_with: bool = False,
        ignore_case: bool = True,
        time_out: int = 60,
    ) -> list | str:
        """Locate string value in elements that are anchored to assets.  Async Version.
        Asset: https: // egeria - project.org / concepts / asset /

        Parameters
        ----------
        search_string : str
            The string used for searching engine actions by name.

        starts_with : bool, optional
            Whether to search engine actions that start with the given search string. Default is False.

        ends_with : bool, optional
            Whether to search engine actions that end with the given search string. Default is False.

        ignore_case : bool, optional
            Whether to ignore case while searching engine actions. Default is False.

        start_from : int, optional
            The index from which to start fetching the engine actions. Default is 0.

        page_size : int, optional
            The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

        Returns
        -------
        List[dict] or str
            A list of dictionaries representing the engine actions found based on the search query.
            If no actions are found, returns the string "no actions".

        Raises:
        ------
        InvalidParameterException
        PropertyServerException
        UserNotAuthorizedException

        Notes
        -----
        For more information see: https://egeria-project.org/concepts/engine-action
        """

        validate_search_string(search_string)

        starts_with_s = str(starts_with).lower()
        ends_with_s = str(ends_with).lower()
        ignore_case_s = str(ignore_case).lower()

        url = (
            f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/asset-catalog/assets/in-domain/"
            f"by-search-string?startFrom={start_from}&pageSize={page_size}&startsWith={starts_with_s}&"
            f"endWith={ends_with_s}&ignoreCase={ignore_case_s}"
        )
        body = {"filter": search_string}
        response = await self._async_make_request("POST", url, body, time_out=time_out)
        return response.json().get("searchMatches", "NO_ASSETS_FOUND")

    def find_in_asset_domain(
        self,
        search_string: str,
        start_from: int = 0,
        page_size: int = max_paging_size,
        starts_with: bool = True,
        ends_with: bool = False,
        ignore_case: bool = True,
        time_out: int = 60,
    ) -> list | str:
        """Retrieve the list of engine action metadata elements that contain the search string. Async Version.
        Parameters
        ----------
        search_string : str
            The string used for searching engine actions by name.

        starts_with : bool, optional
            Whether to search engine actions that start with the given search string. Default is False.

        ends_with : bool, optional
            Whether to search engine actions that end with the given search string. Default is False.

        ignore_case : bool, optional
            Whether to ignore case while searching engine actions. Default is False.

        start_from : int, optional
            The index from which to start fetching the engine actions. Default is 0.

        page_size : int, optional
            The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

        Returns
        -------
        List[dict] or str
            A list of dictionaries representing the engine actions found based on the search query.
            If no actions are found, returns the string "no actions".

        Raises:
        ------
        InvalidParameterException
        PropertyServerException
        UserNotAuthorizedException

        Notes
        -----
        For more information see: https://egeria-project.org/concepts/engine-action
        """
        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_find_in_asset_domain(
                search_string,
                start_from,
                page_size,
                starts_with,
                ends_with,
                ignore_case,
                time_out,
            )
        )
        return response

    async def _async_get_asset_graph(
        self,
        asset_guid: str,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str | dict:
        """Return all the elements that are anchored to an asset plus relationships between these elements and to
          other elements. Async Version.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        dict or str
             A dictionary of the asset graph.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        url = (
            f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/asset-catalog/assets/{asset_guid}/"
            f"as-graph?startFrom={start_from}&pageSize={page_size}"
        )

        response = await self._async_make_request("POST", url)
        return response.json().get("assetGraph", NO_ASSETS_FOUND)

    def get_asset_graph(
        self,
        asset_guid: str,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str | dict:
        """Return all the elements that are anchored to an asset plus relationships between these elements and to
          other elements.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        dict or str
             A dictionary of the asset graph.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_get_asset_graph(asset_guid, start_from, page_size)
        )
        return response

    def get_asset_mermaid_graph(
        self,
        asset_guid: str,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str:
        """Return the asset graph as mermaid markdown string.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        str
             A mermaid string representing the asset graph.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        asset_graph = self.get_asset_graph(asset_guid, start_from, page_size)
        return asset_graph.get("mermaidGraph")

    async def _async_get_asset_lineage_graph(
        self,
        asset_guid: str,
        effective_time: str = None,
        as_of_time: str = None,
        relationship_types: [str] = None,
        limit_to_isc_q_name: str = None,
        hilight_isc_q_name: str = None,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str | dict:
        """Return the asset lineage including a mermaid markdown string. Async Version.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.
         effective_time: str, default is None
            Effective time to query on. If not specified, the current time is used.
         as_of_time: str = None
            as_of_time to query on. If not specified, the current time is used.
         relationship_types: [str], default is None,
            relationship types to include in the lineage graph. If not specified, all relationship types are included.
         limit_to_isc_q_name: str = None,
            if specified, filters results to only include information supply chains with the given name.
         hilight_isc_q_name: str = None,
            if specified, highlights the information supply chain with the given name.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        str | dict
             A dictionary of the asset graph that includes a mermaid markdown string.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        url = (
            f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/asset-catalog/assets/{asset_guid}/"
            f"as-lineage-graph?startFrom={start_from}&pageSize={page_size}"
        )
        body = {
            "effectiveTime": effective_time,
            "asOfTime": as_of_time,
            "relationshipTypes": relationship_types,
            "limitToISCQualifiedName": limit_to_isc_q_name,
            "highlightISCQualifiedName": hilight_isc_q_name,
            }
        response = await self._async_make_request("POST", url, body_slimmer(body))
        return response.json().get("assetLineageGraph", NO_ASSETS_FOUND)

    def get_asset_lineage_graph(
        self,
        asset_guid: str,
        effective_time: str = None,
        as_of_time: str = None,
        relationship_types: [str] = None,
        limit_to_isc_q_name: str = None,
        hilight_isc_q_name: str = None,
        start_from: int = 0,
        page_size: int = max_paging_size,
        ) -> str | dict:
        """Return the asset lineage including a mermaid markdown string. Async Version.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.
        effective_time: str, default is None
            Effective time to query on. If not specified, the current time is used.
        as_of_time: str = None
            as_of_time to query on. If not specified, the current time is used.
        relationship_types: [str], default is None,
            relationship types to include in the lineage graph. If not specified, all relationship types are included.
        limit_to_isc_q_name: str = None,
            if specified, filters results to only include information supply chains with the given name.
        hilight_isc_q_name: str = None,
            if speficied, highlights the information supply chain with the given name.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of elements to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        dict or str
             A dictionary of the asset graph.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_get_asset_lineage_graph(asset_guid, effective_time, as_of_time, relationship_types,
                                                limit_to_isc_q_name, hilight_isc_q_name, start_from, page_size)
        )
        return response

    def get_asset_lineage_mermaid_graph(
        self,
        asset_guid: str,
        effective_time: str = None,
        as_of_time: str = None,
        relationship_types: [str] = None,
        limit_to_isc_q_name: str = None,
        hilight_isc_q_name: str = None,
        start_from: int = 0,
        page_size: int = max_paging_size,
        ) -> str:
        """Return the asset lineage including a mermaid markdown string. Async Version.
         Parameters
         ----------
         asset_guid : str
             The unique identity of the asset to get the graph for.
        effective_time: str, default is None
            Effective time to query on. If not specified, the current time is used.
        as_of_time: str = None
            as_of_time to query on. If not specified, the current time is used.
        relationship_types: [str], default is None,
            relationship types to include in the lineage graph. If not specified, all relationship types are included.
        limit_to_isc_q_name: str = None,
            if specified, filters results to only include information supply chains with the given name.
        hilight_isc_q_name: str = None,
            if specified, highlights the information supply chain with the given name.

         start_from : int, optional
             The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
             The maximum number of elements to fetch in a single request.
             Default is `max_paging_size`.

        Returns
         -------
        str
             A mermaid string representing the lineage.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

    """

        asset_graph = self.get_asset_lineage_graph(asset_guid, effective_time,
                                                   as_of_time, relationship_types,
                                                   limit_to_isc_q_name, hilight_isc_q_name,
                                                   start_from, page_size)
        return asset_graph.get("mermaidGraph")

    async def _async_get_assets_by_metadata_collection_id(
        self,
        metadata_collection_id: str,
        type_name: str = None,
        effective_time: str = None,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str | list:
        """Return a list of assets that come from the requested metadata collection. Can optionally
         specify an type name as a filter and an effective time. Async Version.

         Parameters
         ----------
         metadata_collection_id : str
            The unique identity of the metadata collection to return assets from.

         type_name: str, optional
             An asset type to optionally filter on. If not specified, all assets in the collection will be returned.

         effective_time: str, optional
             The effective time to filter on. If not specified, the current time is used.

         start_from : int, optional
            The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
            The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        list or str
            A list of assets in a [dict].

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        url = (
            f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/asset-catalog/assets/by-metadata-collection-id/"
            f"{metadata_collection_id}?startFrom={start_from}&pageSize={page_size}"
        )

        body = {"filter": type_name, "effectiveTime": effective_time}
        body_s = body_slimmer(body)
        response = await self._async_make_request("POST", url, body_s)
        return response.json().get("assets", "NO_ASSETS_FOUND")

    def get_assets_by_metadata_collection_id(
        self,
        metadata_collection_id: str,
        type_name: str = None,
        effective_time: str = None,
        start_from: int = 0,
        page_size: int = max_paging_size,
    ) -> str | list:
        """Return a list of assets that come from the requested metadata collection. Can optionally
         specify an type name as a filter and an effective time. Async Version.

         Parameters
         ----------
         metadata_collection_id : str
            The unique identity of the metadata collection to return assets from.

         type_name: str, optional
             An asset type to optionally filter on. If not specified, all assets in the collection will be returned.

         effective_time: str, optional
             The effective time to filter on. If not specified, the current time is used.

         start_from : int, optional
            The index from which to start fetching the engine actions. Default is 0.

         page_size : int, optional
            The maximum number of engine actions to fetch in a single request. Default is `max_paging_size`.

         Returns
         -------
        list or str
            A list of assets in a [dict].

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(
            self._async_get_assets_by_metadata_collection_id(
                metadata_collection_id,
                type_name,
                effective_time,
                start_from,
                page_size,
            )
        )
        return response

    async def _async_get_asset_types(self) -> str | dict:
        """Return all the elements that are anchored to an asset plus relationships between these elements and to
         other elements. Async Version.
        Parameters
        ----------

        Returns
        -------
        dict or str
            A dictionary of the asset graph.

        Raises:
        ------
        InvalidParameterException
        PropertyServerException
        UserNotAuthorizedException

        """

        url = f"{self.platform_url}/servers/{self.view_server}/api/open-metadata/asset-catalog/assets/types"

        response = await self._async_make_request("GET", url)

        return response.json().get("types", "NO_ASSETS_FOUND")

    def get_asset_types(self) -> str | dict:
        """Return all the elements that are anchored to an asset plus relationships between these elements and to
          other elements.
         Parameters
         ----------

         Returns
         -------
        dict or str
             A dictionary of the asset graph.

         Raises:
         ------
         InvalidParameterException
         PropertyServerException
         UserNotAuthorizedException

        """

        loop = asyncio.get_event_loop()
        response = loop.run_until_complete(self._async_get_asset_types())
        return response


if __name__ == "__main__":
    print("Main-asset-catalog")



"""
This file contains general utility functions for processing Egeria Markdown
"""
import json
import os
import sys
from datetime import datetime
from typing import List

from loguru import logger
from rich import print
from rich.console import Console
from rich.markdown import Markdown

from commands.cat.dr_egeria_command_help import EGERIA_INBOX_PATH
from md_processing.md_processing_utils.common_md_utils import (get_current_datetime_string, get_element_dictionary,
                                                               update_element_dictionary,
                                                               split_tb_string, str_to_bool, )
from md_processing.md_processing_utils.extraction_utils import (process_simple_attribute, extract_attribute,
                                                                get_element_by_name)
from md_processing.md_processing_utils.md_processing_constants import (get_command_spec, load_commands, load_commands,
                                                                       COMMAND_DEFINITIONS,
                                                                       add_default_upsert_attributes,
                                                                       add_default_link_attributes)

from md_processing.md_processing_utils.message_constants import (ERROR, INFO, WARNING, ALWAYS, EXISTS_REQUIRED)
from pyegeria import EgeriaTech
from pyegeria._globals import DEBUG_LEVEL
from pyegeria.output_formatter import generate_entity_md_table, populate_columns_from_properties

# Constants
EGERIA_WIDTH = int(os.environ.get("EGERIA_WIDTH", "200"))
EGERIA_ROOT_PATH = os.environ.get("EGERIA_ROOT_PATH", ".")
EGERIA_INBOX_PATH = os.environ.get("EGERIA_INBOX_PATH", ".")

console = Console(width=EGERIA_WIDTH)

debug_level = DEBUG_LEVEL
global COMMAND_DEFINITIONS

load_commands('commands.json')


log_format = "D {time} | {level} | {function} | {line} | {message} | {extra}"
logger.remove()
logger.add(sys.stderr, level="INFO", format=log_format, colorize=True)
full_file_path = os.path.join(EGERIA_ROOT_PATH, EGERIA_INBOX_PATH, "data_designer_debug.log")
# logger.add(full_file_path, rotation="1 day", retention="1 week", compression="zip", level="TRACE", format=log_format,
#            colorize=True)
logger.add("debug_log", rotation="1 day", retention="1 week", compression="zip", level="TRACE", format=log_format,
           colorize=True)
def get_iso8601_datetime():
    """Returns the current date and time in ISO 8601 format."""
    return datetime.now().strftime('%Y-%m-%dT%H:%M:%S')

def yes_no(input: str)->str:
    if type(input) is bool:
        if input:
            return "True"
        else:
            return "False"

    input = input.title()
    if input in ["Yes","No"]:
        return input

    if input in ["True", "T"]:
        return "Yes"
    else:
        return "No"

@logger.catch
def _extract_help_fields(command: dict):
    """
    Build a list of attribute dictionaries for a given command spec.
    This prepares the data rows used to render the help table.
    """

    command_spec = get_command_spec(command)
    verb = command_spec.get('verb', None)
    if verb == "Create":
        distinguished_attributes = command_spec.get('Attributes', [])
        attributes = add_default_upsert_attributes(distinguished_attributes)
    elif verb in ["Link","Attach"]  :
        distinguished_attributes = command_spec.get('Attributes', [])
        attributes = add_default_link_attributes(distinguished_attributes)
    else:
        attributes = command_spec.get('Attributes', [])


    term_entry: list = []
    for attr in attributes:
        for key in attr:
            if attr[key].get('level', 'Basic') != "Basic":
                continue
            attribute_name = key
            input_required = yes_no(attr[key].get('input_required', "No"))

            read_only = yes_no(attr[key].get('user_specified', "No"))
            generated = yes_no(attr[key].get('generated', "No"))
            default = attr[key].get('default', None)
            if default:
                generated = default
            unique = yes_no(attr[key].get('unique', "No"))
            notes = attr[key].get('description', "")
            valid_values = attr[key].get('valid_values', [])
            term_entry.append({
                'Attribute Name': attribute_name,
                'Input Required': input_required,
                'Read Only': read_only,
                'Generated': generated,
                'Default Value': default,
                'Notes': notes,
                'Unique Values': unique,
                'Valid Values': valid_values,
            })

    return term_entry

@logger.catch
def _extract_help_function(element: dict, columns_struct: dict) -> dict:
    """
    Return a populated columns data structure matching the signature and structure
    of _extract_glossary_properties in glossary_manager.

    Args:
        element: One row (dict) describing a help attribute with keys matching columns_struct
        columns_struct: Dict containing formats->columns definitions

    Returns:
        dict: A structure with key 'formats' and a 'columns' list whose entries have
              their 'value' fields populated from the element dict.
    """
    # Normalize to a shape compatible with populate_columns_from_properties
    normalized = {
        'properties': element or {},
        'elementHeader': {},
    }
    col_data = populate_columns_from_properties(normalized, columns_struct)
    return col_data

def create_help_terms():
    term_entry:str = ""
    glossary_name = "Egeria-Markdown"
    commands = COMMAND_DEFINITIONS["Command Specifications"]
    columns = [{'name': "Attribute Name", 'key': 'Attribute Name'},
               {'name': 'Input Required', 'key': 'Input Required'},
               {'name': 'Read Only', 'key': 'Read Only'},
               {'name': 'Generated', 'key': 'Generated'},
               {'name': 'Default Value', 'key': 'Default Value'},
               {'name': 'Notes', 'key': 'Notes'},
               {'name': 'Unique Values', 'key': 'Unique Values'},
               {'name': 'Valid Values', 'key': 'Valid Values'}]
    columns_struct = {"target_type": "Term", "formats": {
                                          "types": "ALL",
                                        "attributes": columns}
                      }

    term_entry = """# Generating glossary entries for the documented commands\n\n
            This file contains generated Dr.Egeria commands to generate glossary term entries describing
            each Dr.Egeria command. 

> Usage: Before executing this file, make sure you have a glossary named `Egeria-Markdown`
> already created. If you Need to create one, you can use the `hey_egeria tui` command.\n"""

    for command, values in commands.items():
        if command == "exported":
            continue
        if commands[command].get("level","") not in ["Basic"]:
            continue
        command_description = commands[command].get("description","")
        command_verb = commands[command].get("verb","")

        term_entry+= "# Create Term\n"
        term_entry+= f"## Term Name\n\n{command}\n\n"
        term_entry+= f"## Description\n\n{command_description}\n\n"
        term_entry+= f"## Glossary\n\n{glossary_name}\n\n"
        term_entry+= f"## Folders\n\nWriting Dr.Egeria Markdown\n\n"


        du = _extract_help_fields(command)
        output = generate_entity_md_table(du, "", "", _extract_help_function, columns_struct, None, "help" )

        term_entry+= f"## Usage\n\n{output}\n\n___\n\n"

    print(term_entry)
    # Generate filename with current date and time in ISO 8601 format
    current_datetime = get_iso8601_datetime()
    filename = f"dr-egeria-help-{current_datetime}.md"
    file_path = os.path.join(EGERIA_ROOT_PATH, EGERIA_INBOX_PATH, filename)

    # Write the content to the file
    with open(file_path, 'w', encoding="utf-8") as f:
        f.write(term_entry)

    logger.info(f"Help documentation saved to {file_path}")

def main():
    create_help_terms()


if __name__ == "__main__":
    main()
